@@ -1,3 +1,5 @@
+from asaloader.locale import _
+
 device_list = [
     {
         'name': 'auto',
@@ -5,8 +7,7 @@ device_list = [
         'protocol_version': 0,
         'userapp_start': 0,
         'userapp_size':  0,
-        'note': 'Default, auto detext device type.'
-        # 預設值，選用此參數會自動判斷裝置。
+        'note': _('Default, auto detect device type.')
     },
     {
         'name': 'asa_m128_v1',
